@@ -1,4 +1,3 @@
-
 import os, sys, getopt
 
 import re
@@ -26,20 +25,11 @@ def get_myurl(word,fromLang='auto',toLang = 'zh'):
 def get_translate_word(url):
     try:
         response = requests.get('http://api.fanyi.baidu.com' + url)
-        return response.json()
+        result=response.json()
+        for item in result['trans_result']:
+            cprint (item['dst'], "green")
     except Exception as e:
-        pass
-
-
-def get_response(word):
-    for u in get_myurl(word):
-        get_translate_word(u)
-
-#显示函数
-def show(response):
-    for item in response['trans_result']:
-        cprint (item['dst'], 'green')
-
+        print(e)
 
 def main():
     try:
@@ -50,11 +40,8 @@ def main():
 
     match = re.findall(r'[\w.]+', " ".join(args).lower())
     word = " ".join(match)
-    response = get_response(word)
-    if not response:
-        return
-    show(response)
-
+    for u in get_myurl(word):
+        get_translate_word(u)
 
 if __name__ == '__main__':
     main()
